@@ -108,6 +108,7 @@ class PRepManager(object):
         return self._prep_list
 
     def set_prev_votes(self, block_height: int, block_hash: str, timestamp: int):
+        self._prev_votes.clear()
         if self.prep_list:
             for index, prep in enumerate(self.prep_list):
                 if index == 0:
@@ -120,8 +121,6 @@ class PRepManager(object):
                         "blockHash": block_hash,
                         "signature": "tbears_block_manager_does_not_support_prev_vote_signature"
                     })
-        else:
-            self._prev_votes = []
 
     @property
     def prev_votes(self):
@@ -280,7 +279,8 @@ class BlockManager(object):
         tx_results = response['txResults']
 
         precommit_request = {'blockHeight': hex(block_height),
-                             'blockHash': block_hash}
+                             'oldBlockHash': block_hash,
+                             'newBlockHash': block_hash}
         await self._icon_stub.async_task().write_precommit_state(precommit_request)
 
         tx_result = tx_results[tx_hash]
@@ -535,7 +535,8 @@ class BlockManager(object):
         else:
             tx_list = tx
             for tx_result in tx_results:
-                logs_bloom = logs_bloom + int(tx_result['logsBloom'], 16)
+                if "logsBloom" in tx_result.keys():
+                    logs_bloom = logs_bloom + int(tx_result['logsBloom'], 16)
 
         block_height = self.block.block_height + 1
 
